@@ -49,10 +49,8 @@ const (
 )
 
 var (
-	lineEndingRx     = regexp.MustCompile(`(?m)(?:\r\n|\r|\n)`)
-	modifyTemplateRx = regexp.MustCompile(
-		`(?m)^.*chezmoi:modify-template.*$(?:\r?\n)?`,
-	)
+	lineEndingRx                    = regexp.MustCompile(`(?m)(?:\r\n|\r|\n)`)
+	modifyTemplateRx                = regexp.MustCompile(`(?m)^.*chezmoi:modify-template.*$(?:\r?\n)?`)
 	templateDirectiveRx             = regexp.MustCompile(`(?m)^.*?chezmoi:template:(.*)$(?:\r?\n)?`)
 	templateDirectiveKeyValuePairRx = regexp.MustCompile(`\s*(\S+)=("(?:[^"]|\\")*"|\S+)`)
 
@@ -131,6 +129,7 @@ type SourceState struct {
 	defaultTemplateDataFunc func() map[string]any
 	templateDataOnly        bool
 	readTemplateData        bool
+	readTemplates           bool
 	defaultTemplateData     map[string]any
 	userTemplateData        map[string]any
 	priorityTemplateData    map[string]any
@@ -222,6 +221,13 @@ func WithReadTemplateData(readTemplateData bool) SourceStateOption {
 	}
 }
 
+// WithReadTemplates sets whether to read .chezmoitemplates directories.
+func WithReadTemplates(readTemplates bool) SourceStateOption {
+	return func(s *SourceState) {
+		s.readTemplates = readTemplates
+	}
+}
+
 // WithSourceDir sets the source directory.
 func WithSourceDir(sourceDirAbsPath AbsPath) SourceStateOption {
 	return func(s *SourceState) {
@@ -286,6 +292,7 @@ func NewSourceState(options ...SourceStateOption) *SourceState {
 		httpClient:           http.DefaultClient,
 		logger:               &log.Logger,
 		readTemplateData:     true,
+		readTemplates:        true,
 		priorityTemplateData: make(map[string]any),
 		userTemplateData:     make(map[string]any),
 		templateOptions:      DefaultTemplateOptions,
@@ -360,11 +367,8 @@ func (s *SourceState) Add(
 				continue
 			}
 			if strings.HasPrefix(destAbsPath.String(), protectedAbsPath.String()) {
-				return fmt.Errorf(
-					"%s: cannot add chezmoi file to chezmoi (%s is protected)",
-					destAbsPath,
-					protectedAbsPath,
-				)
+				format := "%s: cannot add chezmoi file to chezmoi (%s is protected)"
+				return fmt.Errorf(format, destAbsPath, protectedAbsPath)
 			}
 		}
 	}
@@ -402,9 +406,7 @@ DEST_ABS_PATH:
 		if err != nil {
 			return err
 		}
-		newSourceStateEntry, err := s.sourceStateEntry(
-			actualStateEntry, destAbsPath, destAbsPathInfo, parentSourceRelPath, options,
-		)
+		newSourceStateEntry, err := s.sourceStateEntry(actualStateEntry, destAbsPath, destAbsPathInfo, parentSourceRelPath, options)
 		if err != nil {
 			return err
 		}
@@ -508,31 +510,28 @@ DEST_ABS_PATH:
 	// all existing source state entries that are in options.RemoveDir and not
 	// in the new source state.
 	if options.RemoveDir != EmptyRelPath {
-		_ = s.root.ForEach(
-			EmptyRelPath,
-			func(targetRelPath RelPath, sourceStateEntry SourceStateEntry) error {
-				if !targetRelPath.HasDirPrefix(options.RemoveDir) {
-					return nil
-				}
-				if _, ok := newSourceStateEntriesByTargetRelPath[targetRelPath]; ok {
-					return nil
-				}
-				sourceRelPath := sourceStateEntry.SourceRelPath()
-				sourceRoot.Set(sourceRelPath.RelPath(), &SourceStateRemove{
-					sourceRelPath: sourceRelPath,
-					targetRelPath: targetRelPath,
-				})
-				update := sourceUpdate{
-					destAbsPath: s.destDirAbsPath.Join(targetRelPath),
-					entryState: &EntryState{
-						Type: EntryStateTypeRemove,
-					},
-					sourceRelPaths: []SourceRelPath{sourceRelPath},
-				}
-				sourceUpdates = append(sourceUpdates, update)
+		_ = s.root.ForEach(EmptyRelPath, func(targetRelPath RelPath, sourceStateEntry SourceStateEntry) error {
+			if !targetRelPath.HasDirPrefix(options.RemoveDir) {
 				return nil
-			},
-		)
+			}
+			if _, ok := newSourceStateEntriesByTargetRelPath[targetRelPath]; ok {
+				return nil
+			}
+			sourceRelPath := sourceStateEntry.SourceRelPath()
+			sourceRoot.Set(sourceRelPath.RelPath(), &SourceStateRemove{
+				sourceRelPath: sourceRelPath,
+				targetRelPath: targetRelPath,
+			})
+			update := sourceUpdate{
+				destAbsPath: s.destDirAbsPath.Join(targetRelPath),
+				entryState: &EntryState{
+					Type: EntryStateTypeRemove,
+				},
+				sourceRelPaths: []SourceRelPath{sourceRelPath},
+			}
+			sourceUpdates = append(sourceUpdates, update)
+			return nil
+		})
 	}
 
 	targetSourceState := &SourceState{
@@ -557,9 +556,7 @@ DEST_ABS_PATH:
 			}
 		}
 		if !sourceUpdate.destAbsPath.Empty() {
-			if err := PersistentStateSet(
-				persistentState, EntryStateBucket, sourceUpdate.destAbsPath.Bytes(), sourceUpdate.entryState,
-			); err != nil {
+			if err := PersistentStateSet(persistentState, EntryStateBucket, sourceUpdate.destAbsPath.Bytes(), sourceUpdate.entryState); err != nil {
 				return err
 			}
 		}
@@ -626,9 +623,7 @@ func (s *SourceState) AddDestAbsPathInfos(
 }
 
 // A PreApplyFunc is called before a target is applied.
-type PreApplyFunc func(
-	targetRelPath RelPath, targetEntryState, lastWrittenEntryState, actualEntryState *EntryState,
-) error
+type PreApplyFunc func(targetRelPath RelPath, targetEntryState, lastWrittenEntryState, actualEntryState *EntryState) error
 
 // ApplyOptions are options to SourceState.ApplyAll and SourceState.ApplyOne.
 type ApplyOptions struct {
@@ -683,12 +678,7 @@ func (s *SourceState) Apply(
 	if options.PreApplyFunc != nil {
 		var lastWrittenEntryState *EntryState
 		var entryState EntryState
-		ok, err := PersistentStateGet(
-			persistentState,
-			EntryStateBucket,
-			targetAbsPath.Bytes(),
-			&entryState,
-		)
+		ok, err := PersistentStateGet(persistentState, EntryStateBucket, targetAbsPath.Bytes(), &entryState)
 		if err != nil {
 			return err
 		}
@@ -709,24 +699,14 @@ func (s *SourceState) Apply(
 		// apply as the last written state.
 		if targetEntryState.Equivalent(actualEntryState) &&
 			!lastWrittenEntryState.Equivalent(actualEntryState) {
-			err := PersistentStateSet(
-				persistentState,
-				EntryStateBucket,
-				targetAbsPath.Bytes(),
-				targetEntryState,
-			)
+			err := PersistentStateSet(persistentState, EntryStateBucket, targetAbsPath.Bytes(), targetEntryState)
 			if err != nil {
 				return err
 			}
 			lastWrittenEntryState = targetEntryState
 		}
 
-		err = options.PreApplyFunc(
-			targetRelPath,
-			targetEntryState,
-			lastWrittenEntryState,
-			actualEntryState,
-		)
+		err = options.PreApplyFunc(targetRelPath, targetEntryState, lastWrittenEntryState, actualEntryState)
 		if err != nil {
 			return err
 		}
@@ -738,12 +718,7 @@ func (s *SourceState) Apply(
 		return nil
 	}
 
-	return PersistentStateSet(
-		persistentState,
-		EntryStateBucket,
-		targetAbsPath.Bytes(),
-		targetEntryState,
-	)
+	return PersistentStateSet(persistentState, EntryStateBucket, targetAbsPath.Bytes(), targetEntryState)
 }
 
 // Encryption returns s's encryption.
@@ -832,6 +807,7 @@ func (s *SourceState) MustEntry(targetRelPath RelPath) SourceStateEntry {
 // PostApply performs all updates required after s.Apply.
 func (s *SourceState) PostApply(
 	targetSystem System,
+	persistentState PersistentState,
 	targetDirAbsPath AbsPath,
 	targetRelPaths RelPaths,
 ) error {
@@ -868,6 +844,12 @@ TARGET:
 		default:
 			return err
 		}
+		entryState := &EntryState{
+			Type: EntryStateTypeRemove,
+		}
+		if err := PersistentStateSet(persistentState, EntryStateBucket, targetAbsPath.Bytes(), entryState); err != nil {
+			return err
+		}
 	}
 
 	return nil
@@ -897,9 +879,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 	addSourceStateEntries := func(relPath RelPath, sourceStateEntries ...SourceStateEntry) {
 		allSourceStateEntriesMu.Lock()
 		defer allSourceStateEntriesMu.Unlock()
-		allSourceStateEntries[relPath] = append(
-			allSourceStateEntries[relPath],
-			sourceStateEntries...)
+		allSourceStateEntries[relPath] = append(allSourceStateEntries[relPath], sourceStateEntries...)
 	}
 	walkFunc := func(sourceAbsPath AbsPath, fileInfo fs.FileInfo, err error) error {
 		if err != nil {
@@ -945,8 +925,10 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 			}
 			return s.addTemplateData(sourceAbsPath)
 		case fileInfo.Name() == TemplatesDirName:
-			if err := s.addTemplatesDir(ctx, sourceAbsPath); err != nil {
-				return err
+			if s.readTemplates {
+				if err := s.addTemplatesDir(ctx, sourceAbsPath); err != nil {
+					return err
+				}
 			}
 			return fs.SkipDir
 		case s.templateDataOnly:
@@ -992,24 +974,18 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 			sourceStateDir := s.newSourceStateDir(sourceAbsPath, sourceRelPath, da)
 			addSourceStateEntries(targetRelPath, sourceStateDir)
 			if da.External {
-				sourceStateEntries, err := s.readExternalDir(
-					sourceAbsPath,
-					sourceRelPath,
-					targetRelPath,
-				)
+				sourceStateEntries, err := s.readExternalDir(sourceAbsPath, sourceRelPath, targetRelPath)
 				if err != nil {
 					return err
 				}
 				allSourceStateEntriesMu.Lock()
 				for relPath, entries := range sourceStateEntries {
-					allSourceStateEntries[relPath] = append(
-						allSourceStateEntries[relPath],
-						entries...)
+					allSourceStateEntries[relPath] = append(allSourceStateEntries[relPath], entries...)
 				}
 				allSourceStateEntriesMu.Unlock()
 				return fs.SkipDir
 			}
-			if sourceStateDir.Attr.Type == SourceDirTypeRemove {
+			if sourceStateDir.Attr.Remove {
 				s.Lock()
 				s.removeDirs[targetRelPath] = struct{}{}
 				s.Unlock()
@@ -1024,12 +1000,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 				return nil
 			}
 			var sourceStateEntry SourceStateEntry
-			targetRelPath, sourceStateEntry = s.newSourceStateFile(
-				sourceAbsPath,
-				sourceRelPath,
-				fa,
-				targetRelPath,
-			)
+			targetRelPath, sourceStateEntry = s.newSourceStateFile(sourceAbsPath, sourceRelPath, fa, targetRelPath)
 			addSourceStateEntries(targetRelPath, sourceStateEntry)
 			return nil
 		default:
@@ -1066,13 +1037,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 			case parentSourceStateEntry != nil:
 				parentSourceRelPath = parentSourceStateEntry.SourceRelPath()
 			}
-			externalSourceStateEntries, err := s.readExternal(
-				ctx,
-				externalRelPath,
-				parentSourceRelPath,
-				external,
-				options,
-			)
+			externalSourceStateEntries, err := s.readExternal(ctx, externalRelPath, parentSourceRelPath, external, options)
 			if err != nil {
 				return err
 			}
@@ -1080,9 +1045,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 				if s.Ignore(targetRelPath) {
 					continue
 				}
-				allSourceStateEntries[targetRelPath] = append(
-					allSourceStateEntries[targetRelPath],
-					sourceStateEntries...)
+				allSourceStateEntries[targetRelPath] = append(allSourceStateEntries[targetRelPath], sourceStateEntries...)
 			}
 		}
 	}
@@ -1095,10 +1058,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 	}
 
 	// Generate SourceStateRemoves for existing targets.
-	matches, err := s.remove.glob(
-		s.system.UnderlyingFS(),
-		ensureSuffix(s.destDirAbsPath.String(), "/"),
-	)
+	matches, err := s.remove.glob(s.system.UnderlyingFS(), ensureSuffix(s.destDirAbsPath.String(), "/"))
 	if err != nil {
 		return err
 	}
@@ -1112,10 +1072,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 			sourceRelPath: NewSourceRelPath(".chezmoiremove"),
 			targetRelPath: targetRelPath,
 		}
-		allSourceStateEntries[targetRelPath] = append(
-			allSourceStateEntries[targetRelPath],
-			sourceStateEntry,
-		)
+		allSourceStateEntries[targetRelPath] = append(allSourceStateEntries[targetRelPath], sourceStateEntry)
 	}
 
 	// Generate SourceStateRemoves for exact directories.
@@ -1151,10 +1108,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 					sourceRelPath: sourceStateDir.sourceRelPath,
 					targetRelPath: destEntryRelPath,
 				}
-				allSourceStateEntries[destEntryRelPath] = append(
-					allSourceStateEntries[destEntryRelPath],
-					sourceStateRemove,
-				)
+				allSourceStateEntries[destEntryRelPath] = append(allSourceStateEntries[destEntryRelPath], sourceStateRemove)
 			}
 		case errors.Is(err, fs.ErrNotExist):
 			// Do nothing.
@@ -1200,10 +1154,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 						External: true,
 					},
 				}
-				allSourceStateEntries[externalRelPath] = append(
-					allSourceStateEntries[externalRelPath],
-					sourceStateCommand,
-				)
+				allSourceStateEntries[externalRelPath] = append(allSourceStateEntries[externalRelPath], sourceStateCommand)
 			case err != nil:
 				return err
 			default:
@@ -1224,10 +1175,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 						External: true,
 					},
 				}
-				allSourceStateEntries[externalRelPath] = append(
-					allSourceStateEntries[externalRelPath],
-					sourceStateCommand,
-				)
+				allSourceStateEntries[externalRelPath] = append(allSourceStateEntries[externalRelPath], sourceStateCommand)
 			}
 		}
 	}
@@ -1387,11 +1335,7 @@ func (s *SourceState) addExternalDir(ctx context.Context, externalsDirAbsPath Ab
 
 // addPatterns executes the template at sourceAbsPath, interprets the result as
 // a list of patterns, and adds all patterns found to patternSet.
-func (s *SourceState) addPatterns(
-	patternSet *patternSet,
-	sourceAbsPath AbsPath,
-	sourceRelPath SourceRelPath,
-) error {
+func (s *SourceState) addPatterns(patternSet *patternSet, sourceAbsPath AbsPath, sourceRelPath SourceRelPath) error {
 	data, err := s.executeTemplate(sourceAbsPath)
 	if err != nil {
 		return err
@@ -1547,7 +1491,10 @@ func (s *SourceState) executeTemplate(templateAbsPath AbsPath) ([]byte, error) {
 // getExternalDataRaw returns the raw data for external at externalRelPath,
 // possibly from the external cache.
 func (s *SourceState) getExternalDataRaw(
-	ctx context.Context, externalRelPath RelPath, external *External, options *ReadOptions,
+	ctx context.Context,
+	externalRelPath RelPath,
+	external *External,
+	options *ReadOptions,
 ) ([]byte, error) {
 	var now time.Time
 	if options != nil && options.TimeNow != nil {
@@ -1622,7 +1569,10 @@ func (s *SourceState) getExternalDataRaw(
 // getExternalDataRaw reads the external data for externalRelPath from
 // external.URL.
 func (s *SourceState) getExternalData(
-	ctx context.Context, externalRelPath RelPath, external *External, options *ReadOptions,
+	ctx context.Context,
+	externalRelPath RelPath,
+	external *External,
+	options *ReadOptions,
 ) ([]byte, error) {
 	data, err := s.getExternalDataRaw(ctx, externalRelPath, external, options)
 	if err != nil {
@@ -1633,39 +1583,38 @@ func (s *SourceState) getExternalData(
 
 	if external.Checksum.Size != 0 {
 		if len(data) != external.Checksum.Size {
-			errs = append(errs, fmt.Errorf("size mismatch: expected %d, got %d",
-				external.Checksum.Size, len(data)))
+			err := fmt.Errorf("size mismatch: expected %d, got %d", external.Checksum.Size, len(data))
+			errs = append(errs, err)
 		}
 	}
 
 	if external.Checksum.MD5 != nil {
 		if gotMD5Sum := md5Sum(data); !bytes.Equal(gotMD5Sum, external.Checksum.MD5) {
-			errs = append(errs, fmt.Errorf("MD5 mismatch: expected %s, got %s",
-				external.Checksum.MD5, hex.EncodeToString(gotMD5Sum)))
+			err := fmt.Errorf("MD5 mismatch: expected %s, got %s", external.Checksum.MD5, hex.EncodeToString(gotMD5Sum))
+			errs = append(errs, err)
 		}
 	}
 
 	if external.Checksum.RIPEMD160 != nil {
-		if gotRIPEMD160Sum := ripemd160Sum(data); !bytes.Equal(
-			gotRIPEMD160Sum,
-			external.Checksum.RIPEMD160,
-		) {
-			errs = append(errs, fmt.Errorf("RIPEMD-160 mismatch: expected %s, got %s",
-				external.Checksum.RIPEMD160, hex.EncodeToString(gotRIPEMD160Sum)))
+		if gotRIPEMD160Sum := ripemd160Sum(data); !bytes.Equal(gotRIPEMD160Sum, external.Checksum.RIPEMD160) {
+			format := "RIPEMD-160 mismatch: expected %s, got %s"
+			err := fmt.Errorf(format, external.Checksum.RIPEMD160, hex.EncodeToString(gotRIPEMD160Sum))
+			errs = append(errs, err)
 		}
 	}
 
 	if external.Checksum.SHA1 != nil {
 		if gotSHA1Sum := sha1Sum(data); !bytes.Equal(gotSHA1Sum, external.Checksum.SHA1) {
-			errs = append(errs, fmt.Errorf("SHA1 mismatch: expected %s, got %s",
-				external.Checksum.SHA1, hex.EncodeToString(gotSHA1Sum)))
+			err := fmt.Errorf("SHA1 mismatch: expected %s, got %s", external.Checksum.SHA1, hex.EncodeToString(gotSHA1Sum))
+			errs = append(errs, err)
 		}
 	}
 
 	if external.Checksum.SHA256 != nil {
 		if gotSHA256Sum := SHA256Sum(data); !bytes.Equal(gotSHA256Sum, external.Checksum.SHA256) {
-			errs = append(errs, fmt.Errorf("SHA256 mismatch: expected %s, got %s",
-				external.Checksum.SHA256, hex.EncodeToString(gotSHA256Sum)))
+			format := "SHA256 mismatch: expected %s, got %s"
+			err := fmt.Errorf(format, external.Checksum.SHA256, hex.EncodeToString(gotSHA256Sum))
+			errs = append(errs, err)
 		}
 	}
 
@@ -1708,11 +1657,7 @@ func (s *SourceState) getExternalData(
 }
 
 // newSourceStateDir returns a new SourceStateDir.
-func (s *SourceState) newSourceStateDir(
-	absPath AbsPath,
-	sourceRelPath SourceRelPath,
-	dirAttr DirAttr,
-) *SourceStateDir {
+func (s *SourceState) newSourceStateDir(absPath AbsPath, sourceRelPath SourceRelPath, dirAttr DirAttr) *SourceStateDir {
 	targetStateDir := &TargetStateDir{
 		perm: dirAttr.perm() &^ s.umask,
 	}
@@ -1728,7 +1673,9 @@ func (s *SourceState) newSourceStateDir(
 // file with sourceLazyContents if the file does not already exist, or returns
 // the actual file's contents unchanged if the file already exists.
 func (s *SourceState) newCreateTargetStateEntryFunc(
-	sourceRelPath SourceRelPath, fileAttr FileAttr, sourceLazyContents *lazyContents,
+	sourceRelPath SourceRelPath,
+	fileAttr FileAttr,
+	sourceLazyContents *lazyContents,
 ) targetStateEntryFunc {
 	return func(destSystem System, destAbsPath AbsPath) (TargetStateEntry, error) {
 		var lazyContents *lazyContents
@@ -1771,7 +1718,9 @@ func (s *SourceState) newCreateTargetStateEntryFunc(
 // newFileTargetStateEntryFunc returns a targetStateEntryFunc that returns a
 // file with sourceLazyContents.
 func (s *SourceState) newFileTargetStateEntryFunc(
-	sourceRelPath SourceRelPath, fileAttr FileAttr, sourceLazyContents *lazyContents,
+	sourceRelPath SourceRelPath,
+	fileAttr FileAttr,
+	sourceLazyContents *lazyContents,
 ) targetStateEntryFunc {
 	return func(destSystem System, destAbsPath AbsPath) (TargetStateEntry, error) {
 		if s.mode == ModeSymlink && !fileAttr.Encrypted && !fileAttr.Executable &&
@@ -1783,9 +1732,7 @@ func (s *SourceState) newFileTargetStateEntryFunc(
 			case isEmpty(contents) && !fileAttr.Empty:
 				return &TargetStateRemove{}, nil
 			default:
-				linkname := normalizeLinkname(
-					s.sourceDirAbsPath.Join(sourceRelPath.RelPath()).String(),
-				)
+				linkname := normalizeLinkname(s.sourceDirAbsPath.Join(sourceRelPath.RelPath()).String())
 				return &TargetStateSymlink{
 					lazyLinkname: newLazyLinkname(linkname),
 					sourceAttr: SourceAttr{
@@ -1928,9 +1875,7 @@ func (s *SourceState) newModifyTargetStateEntryFunc(
 
 // newRemoveTargetStateEntryFunc returns a targetStateEntryFunc that removes a
 // target.
-func (s *SourceState) newRemoveTargetStateEntryFunc(
-	sourceRelPath SourceRelPath, fileAttr FileAttr,
-) targetStateEntryFunc {
+func (s *SourceState) newRemoveTargetStateEntryFunc(sourceRelPath SourceRelPath, fileAttr FileAttr) targetStateEntryFunc {
 	return func(destSystem System, destAbsPath AbsPath) (TargetStateEntry, error) {
 		return &TargetStateRemove{}, nil
 	}
@@ -1978,7 +1923,9 @@ func (s *SourceState) newScriptTargetStateEntryFunc(
 // newSymlinkTargetStateEntryFunc returns a targetStateEntryFunc that returns a
 // symlink with the linkname sourceLazyContents.
 func (s *SourceState) newSymlinkTargetStateEntryFunc(
-	sourceRelPath SourceRelPath, fileAttr FileAttr, sourceLazyContents *lazyContents,
+	sourceRelPath SourceRelPath,
+	fileAttr FileAttr,
+	sourceLazyContents *lazyContents,
 ) targetStateEntryFunc {
 	return func(destSystem System, destAbsPath AbsPath) (TargetStateEntry, error) {
 		linknameFunc := func() (string, error) {
@@ -2008,7 +1955,10 @@ func (s *SourceState) newSymlinkTargetStateEntryFunc(
 // newSourceStateFile returns a possibly new target RalPath and a new
 // SourceStateFile.
 func (s *SourceState) newSourceStateFile(
-	absPath AbsPath, sourceRelPath SourceRelPath, fileAttr FileAttr, targetRelPath RelPath,
+	absPath AbsPath,
+	sourceRelPath SourceRelPath,
+	fileAttr FileAttr,
+	targetRelPath RelPath,
 ) (RelPath, *SourceStateFile) {
 	sourceLazyContents := newLazyContentsFunc(func() ([]byte, error) {
 		contents, err := s.system.ReadFile(s.sourceDirAbsPath.Join(sourceRelPath.RelPath()))
@@ -2027,17 +1977,9 @@ func (s *SourceState) newSourceStateFile(
 	var targetStateEntryFunc targetStateEntryFunc
 	switch fileAttr.Type {
 	case SourceFileTypeCreate:
-		targetStateEntryFunc = s.newCreateTargetStateEntryFunc(
-			sourceRelPath,
-			fileAttr,
-			sourceLazyContents,
-		)
+		targetStateEntryFunc = s.newCreateTargetStateEntryFunc(sourceRelPath, fileAttr, sourceLazyContents)
 	case SourceFileTypeFile:
-		targetStateEntryFunc = s.newFileTargetStateEntryFunc(
-			sourceRelPath,
-			fileAttr,
-			sourceLazyContents,
-		)
+		targetStateEntryFunc = s.newFileTargetStateEntryFunc(sourceRelPath, fileAttr, sourceLazyContents)
 	case SourceFileTypeModify:
 		// If the target has an extension, determine if it indicates an
 		// interpreter to use.
@@ -2048,12 +1990,7 @@ func (s *SourceState) newSourceStateFile(
 			// of the target name, so remove it.
 			targetRelPath = targetRelPath.Slice(0, targetRelPath.Len()-len(extension)-1)
 		}
-		targetStateEntryFunc = s.newModifyTargetStateEntryFunc(
-			sourceRelPath,
-			fileAttr,
-			sourceLazyContents,
-			interpreter,
-		)
+		targetStateEntryFunc = s.newModifyTargetStateEntryFunc(sourceRelPath, fileAttr, sourceLazyContents, interpreter)
 	case SourceFileTypeRemove:
 		targetStateEntryFunc = s.newRemoveTargetStateEntryFunc(sourceRelPath, fileAttr)
 	case SourceFileTypeScript:
@@ -2062,14 +1999,14 @@ func (s *SourceState) newSourceStateFile(
 		extension := strings.ToLower(strings.TrimPrefix(targetRelPath.Ext(), "."))
 		interpreter := s.interpreters[extension]
 		targetStateEntryFunc = s.newScriptTargetStateEntryFunc(
-			sourceRelPath, fileAttr, targetRelPath, sourceLazyContents, interpreter,
-		)
-	case SourceFileTypeSymlink:
-		targetStateEntryFunc = s.newSymlinkTargetStateEntryFunc(
 			sourceRelPath,
 			fileAttr,
+			targetRelPath,
 			sourceLazyContents,
+			interpreter,
 		)
+	case SourceFileTypeSymlink:
+		targetStateEntryFunc = s.newSymlinkTargetStateEntryFunc(sourceRelPath, fileAttr, sourceLazyContents)
 	default:
 		panic(fmt.Sprintf("%d: unsupported type", fileAttr.Type))
 	}
@@ -2149,9 +2086,7 @@ func (s *SourceState) newSourceStateFileEntryFromFile(
 		}
 	}
 	lazyContents := newLazyContents(contents)
-	sourceRelPath := parentSourceRelPath.Join(
-		NewSourceRelPath(fileAttr.SourceName(s.encryption.EncryptedSuffix())),
-	)
+	sourceRelPath := parentSourceRelPath.Join(NewSourceRelPath(fileAttr.SourceName(s.encryption.EncryptedSuffix())))
 	return &SourceStateFile{
 		Attr:          fileAttr,
 		origin:        actualStateFile,
@@ -2168,7 +2103,9 @@ func (s *SourceState) newSourceStateFileEntryFromFile(
 // newSourceStateFileEntryFromSymlink returns a SourceStateEntry constructed
 // from a symlink in s.
 func (s *SourceState) newSourceStateFileEntryFromSymlink(
-	actualStateSymlink *ActualStateSymlink, fileInfo fs.FileInfo, parentSourceRelPath SourceRelPath,
+	actualStateSymlink *ActualStateSymlink,
+	fileInfo fs.FileInfo,
+	parentSourceRelPath SourceRelPath,
 	options *AddOptions,
 ) (*SourceStateFile, error) {
 	linkname, err := actualStateSymlink.Linkname()
@@ -2199,9 +2136,7 @@ func (s *SourceState) newSourceStateFileEntryFromSymlink(
 		Type:       SourceFileTypeSymlink,
 		Template:   template,
 	}
-	sourceRelPath := parentSourceRelPath.Join(
-		NewSourceRelPath(fileAttr.SourceName(s.encryption.EncryptedSuffix())),
-	)
+	sourceRelPath := parentSourceRelPath.Join(NewSourceRelPath(fileAttr.SourceName(s.encryption.EncryptedSuffix())))
 	return &SourceStateFile{
 		Attr:          fileAttr,
 		sourceRelPath: sourceRelPath,
@@ -2213,6 +2148,25 @@ func (s *SourceState) newSourceStateFileEntryFromSymlink(
 	}, nil
 }
 
+// populateImplicitDirs creates implicit parent directories for externalRelPath.
+func (s *SourceState) populateImplicitParentDirs(
+	externalRelPath RelPath,
+	external *External,
+	sourceStateEntries map[RelPath][]SourceStateEntry,
+) map[RelPath][]SourceStateEntry {
+	for relPath := externalRelPath.Dir(); relPath != DotRelPath; relPath = relPath.Dir() {
+		sourceStateEntries[relPath] = append(sourceStateEntries[relPath],
+			&SourceStateImplicitDir{
+				origin: external,
+				targetStateEntry: &TargetStateDir{
+					perm: fs.ModePerm &^ s.umask,
+				},
+			},
+		)
+	}
+	return sourceStateEntries
+}
+
 // readExternal reads an external and returns its SourceStateEntries.
 func (s *SourceState) readExternal(
 	ctx context.Context,
@@ -2225,13 +2179,7 @@ func (s *SourceState) readExternal(
 	case ExternalTypeArchive:
 		return s.readExternalArchive(ctx, externalRelPath, parentSourceRelPath, external, options)
 	case ExternalTypeArchiveFile:
-		return s.readExternalArchiveFile(
-			ctx,
-			externalRelPath,
-			parentSourceRelPath,
-			external,
-			options,
-		)
+		return s.readExternalArchiveFile(ctx, externalRelPath, parentSourceRelPath, external, options)
 	case ExternalTypeFile:
 		return s.readExternalFile(ctx, externalRelPath, parentSourceRelPath, external, options)
 	case ExternalTypeGitRepo:
@@ -2403,7 +2351,7 @@ func (s *SourceState) readExternalArchive(
 		return nil, fmt.Errorf("%s: %s: %w", externalRelPath, external.URL, err)
 	}
 
-	return sourceStateEntries, nil
+	return s.populateImplicitParentDirs(externalRelPath, external, sourceStateEntries), nil
 }
 
 // readExternalArchiveData reads an external archive's data and returns its data
@@ -2421,12 +2369,8 @@ func (s *SourceState) readExternalArchiveData(
 
 	url, err := url.Parse(external.URL)
 	if err != nil {
-		return nil, ArchiveFormatUnknown, fmt.Errorf(
-			"%s: %s: %w",
-			externalRelPath,
-			external.URL,
-			err,
-		)
+		err := fmt.Errorf("%s: %s: %w", externalRelPath, external.URL, err)
+		return nil, ArchiveFormatUnknown, err
 	}
 	urlPath := url.Path
 	if external.Encrypted {
@@ -2543,14 +2487,16 @@ func (s *SourceState) readExternalArchiveFile(
 		return nil, fmt.Errorf("%s: path not found in %s", external.ArchivePath, external.URL)
 	}
 
-	return map[RelPath][]SourceStateEntry{
+	return s.populateImplicitParentDirs(externalRelPath, external, map[RelPath][]SourceStateEntry{
 		externalRelPath: {sourceStateEntry},
-	}, nil
+	}), nil
 }
 
 // ReadExternalDir returns all source state entries in an external_ dir.
 func (s *SourceState) readExternalDir(
-	rootSourceAbsPath AbsPath, rootSourceRelPath SourceRelPath, rootTargetRelPath RelPath,
+	rootSourceAbsPath AbsPath,
+	rootSourceRelPath SourceRelPath,
+	rootTargetRelPath RelPath,
 ) (map[RelPath][]SourceStateEntry, error) {
 	sourceStateEntries := make(map[RelPath][]SourceStateEntry)
 	walkFunc := func(absPath AbsPath, fileInfo fs.FileInfo, err error) error {
@@ -2632,10 +2578,7 @@ func (s *SourceState) readExternalDir(
 				},
 			}
 		}
-		sourceStateEntries[targetRelPath] = append(
-			sourceStateEntries[targetRelPath],
-			sourceStateEntry,
-		)
+		sourceStateEntries[targetRelPath] = append(sourceStateEntries[targetRelPath], sourceStateEntry)
 		return nil
 	}
 	if err := Walk(s.system, rootSourceAbsPath, walkFunc); err != nil {
@@ -2674,15 +2617,13 @@ func (s *SourceState) readExternalFile(
 		),
 		targetStateEntry: targetStateEntry,
 	}
-	return map[RelPath][]SourceStateEntry{
+	return s.populateImplicitParentDirs(externalRelPath, external, map[RelPath][]SourceStateEntry{
 		externalRelPath: {sourceStateEntry},
-	}, nil
+	}), nil
 }
 
 // readScriptsDir reads all scripts in scriptsDirAbsPath.
-func (s *SourceState) readScriptsDir(
-	ctx context.Context, scriptsDirAbsPath AbsPath,
-) (map[RelPath][]SourceStateEntry, error) {
+func (s *SourceState) readScriptsDir(ctx context.Context, scriptsDirAbsPath AbsPath) (map[RelPath][]SourceStateEntry, error) {
 	var allSourceStateEntriesMu sync.Mutex
 	allSourceStateEntries := make(map[RelPath][]SourceStateEntry)
 	addSourceStateEntry := func(relPath RelPath, sourceStateEntry SourceStateEntry) {
@@ -2743,12 +2684,7 @@ func (s *SourceState) readScriptsDir(
 				return nil
 			}
 			var sourceStateEntry SourceStateEntry
-			targetRelPath, sourceStateEntry = s.newSourceStateFile(
-				sourceAbsPath,
-				sourceRelPath,
-				fa,
-				targetRelPath,
-			)
+			targetRelPath, sourceStateEntry = s.newSourceStateFile(sourceAbsPath, sourceRelPath, fa, targetRelPath)
 			addSourceStateEntry(targetRelPath, sourceStateEntry)
 			return nil
 		default:
@@ -2818,19 +2754,39 @@ func (e *External) OriginString() string {
 // allEquivalentDirs returns if sourceStateEntries are all equivalent
 // directories.
 func allEquivalentDirs(sourceStateEntries []SourceStateEntry) bool {
-	sourceStateDir0, ok := sourceStateEntries[0].(*SourceStateDir)
-	if !ok {
+	// Find all directories to check for equivalence.
+	var firstSourceStateDir *SourceStateDir
+	sourceStateDirs := make([]SourceStateEntry, 0, len(sourceStateEntries))
+	for _, sourceStateEntry := range sourceStateEntries {
+		switch sourceStateEntry := sourceStateEntry.(type) {
+		case *SourceStateDir:
+			firstSourceStateDir = sourceStateEntry
+			sourceStateDirs = append(sourceStateDirs, sourceStateEntry)
+		case *SourceStateImplicitDir:
+			sourceStateDirs = append(sourceStateDirs, sourceStateEntry)
+		default:
+			return false
+		}
+	}
+
+	// If there are no SourceStateDirs then there are no equivalent directories.
+	if len(sourceStateDirs) == 0 {
 		return false
 	}
-	for _, sourceStateEntry := range sourceStateEntries[1:] {
-		sourceStateDir, ok := sourceStateEntry.(*SourceStateDir)
-		if !ok {
-			return false
-		}
-		if sourceStateDir0.Attr != sourceStateDir.Attr {
-			return false
+
+	// Check for equivalence.
+	for _, sourceStateDir := range sourceStateDirs {
+		switch sourceStateDir := sourceStateDir.(type) {
+		case *SourceStateDir:
+			if sourceStateDir.Attr != firstSourceStateDir.Attr {
+				return false
+			}
+		case *SourceStateImplicitDir:
+			// SourceStateImplicitDirs are considered equivalent to all other
+			// directories.
 		}
 	}
+
 	return true
 }
 
