@@ -343,6 +343,7 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			ifNotExist:  checkResultInfo,
 			versionArgs: []string{"--version"},
 			versionRx:   regexp.MustCompile(`^(\d+\.\d+\.\d+)`),
+			minVersion:  &keepassxcMinVersion,
 		},
 		&fileCheck{
 			name:       "keepassxc-db",
@@ -464,7 +465,7 @@ func (c *binaryCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath)
 	var pathAbsPath chezmoi.AbsPath
 	switch path, err := chezmoi.LookPath(c.binaryname); {
 	case errors.Is(err, exec.ErrNotFound):
-		return c.ifNotExist, fmt.Sprintf("%s not found in $PATH", c.binaryname)
+		return c.ifNotExist, c.binaryname + " not found in $PATH"
 	case err != nil:
 		return checkResultFailed, err.Error()
 	default:
@@ -550,7 +551,7 @@ func (c *configFileCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsP
 			filenameStrs = append(filenameStrs, filenameAbsPath.String())
 		}
 		sort.Strings(filenameStrs)
-		return checkResultWarning, fmt.Sprintf("%s: multiple config files", englishList(filenameStrs))
+		return checkResultWarning, englishList(filenameStrs) + ": multiple config files"
 	}
 }
 
@@ -576,6 +577,7 @@ func (c *dirCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (c
 			"status",
 			"--porcelain=v2",
 		)
+		cmd.Stderr = os.Stderr
 		output, err := cmd.Output()
 		if err != nil {
 			gitStatus = gitStatusError
