@@ -2,43 +2,44 @@ package cmd
 
 import (
 	"bytes"
+	"io/fs"
 	"strings"
 	"testing"
 
-	"github.com/stretchr/testify/require"
+	"github.com/alecthomas/assert/v2"
 	"github.com/twpayne/go-vfs/v4"
 	"github.com/twpayne/go-vfs/v4/vfst"
 
-	"github.com/twpayne/chezmoi/v2/internal/archive"
+	"github.com/twpayne/chezmoi/v2/internal/archivetest"
 	"github.com/twpayne/chezmoi/v2/internal/chezmoitest"
 )
 
 func TestImportCmd(t *testing.T) {
-	data, err := archive.NewTar(map[string]interface{}{
-		"archive": map[string]interface{}{
-			".dir": map[string]interface{}{
+	data, err := archivetest.NewTar(map[string]any{
+		"archive": map[string]any{
+			".dir": map[string]any{
 				".file": "# contents of archive/.dir/.file\n",
-				".symlink": &archive.Symlink{
+				".symlink": &archivetest.Symlink{
 					Target: ".file",
 				},
 			},
 		},
 	})
-	require.NoError(t, err)
+	assert.NoError(t, err)
 
 	for _, tc := range []struct {
 		args      []string
-		extraRoot interface{}
-		tests     []interface{}
+		extraRoot any
+		tests     []any
 	}{
 		{
 			args: []string{
 				"--strip-components=1",
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir",
 					vfst.TestIsDir,
-					vfst.TestModePerm(0o777&^chezmoitest.Umask),
+					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/dot_file",
 					vfst.TestModeIsRegular,
@@ -57,13 +58,13 @@ func TestImportCmd(t *testing.T) {
 				"--destination=~/dir",
 				"--strip-components=1",
 			},
-			extraRoot: map[string]interface{}{
-				"/home/user/.local/share/chezmoi/dir": &vfst.Dir{Perm: 0o777},
+			extraRoot: map[string]any{
+				"/home/user/.local/share/chezmoi/dir": &vfst.Dir{Perm: fs.ModePerm},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dir/dot_dir",
 					vfst.TestIsDir,
-					vfst.TestModePerm(0o777&^chezmoitest.Umask),
+					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/dir/dot_dir/dot_file",
 					vfst.TestModeIsRegular,
@@ -83,13 +84,13 @@ func TestImportCmd(t *testing.T) {
 				"--remove-destination",
 				"--strip-components=1",
 			},
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.local/share/chezmoi/dir/file": "# contents of dir/file\n",
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dir/dot_dir",
 					vfst.TestIsDir,
-					vfst.TestModePerm(0o777&^chezmoitest.Umask),
+					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/dir/file",
 					vfst.TestDoesNotExist,
@@ -112,13 +113,13 @@ func TestImportCmd(t *testing.T) {
 				"--exact",
 				"--strip-components=1",
 			},
-			extraRoot: map[string]interface{}{
-				"/home/user/.local/share/chezmoi/dir": &vfst.Dir{Perm: 0o777},
+			extraRoot: map[string]any{
+				"/home/user/.local/share/chezmoi/dir": &vfst.Dir{Perm: fs.ModePerm},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dir/exact_dot_dir",
 					vfst.TestIsDir,
-					vfst.TestModePerm(0o777&^chezmoitest.Umask),
+					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/dir/exact_dot_dir/dot_file",
 					vfst.TestModeIsRegular,
@@ -134,14 +135,14 @@ func TestImportCmd(t *testing.T) {
 		},
 	} {
 		t.Run(strings.Join(tc.args, "_"), func(t *testing.T) {
-			chezmoitest.WithTestFS(t, map[string]interface{}{
-				"/home/user": &vfst.Dir{Perm: 0o777},
+			chezmoitest.WithTestFS(t, map[string]any{
+				"/home/user": &vfst.Dir{Perm: fs.ModePerm},
 			}, func(fileSystem vfs.FS) {
 				if tc.extraRoot != nil {
-					require.NoError(t, vfst.NewBuilder().Build(fileSystem, tc.extraRoot))
+					assert.NoError(t, vfst.NewBuilder().Build(fileSystem, tc.extraRoot))
 				}
 				config := newTestConfig(t, fileSystem, withStdin(bytes.NewReader(data)))
-				require.NoError(t, config.execute(append([]string{"import"}, tc.args...)))
+				assert.NoError(t, config.execute(append([]string{"import"}, tc.args...)))
 				vfst.RunTests(t, fileSystem, "", tc.tests...)
 			})
 		})
