@@ -32,22 +32,12 @@ func (c *Config) newRemoveCmd() *cobra.Command {
 	}
 
 	flags := removeCmd.Flags()
-	flags.BoolVarP(
-		&c.remove.recursive,
-		"recursive",
-		"r",
-		c.remove.recursive,
-		"Recurse into subdirectories",
-	)
+	flags.BoolVarP(&c.remove.recursive, "recursive", "r", c.remove.recursive, "Recurse into subdirectories")
 
 	return removeCmd
 }
 
-func (c *Config) runRemoveCmd(
-	cmd *cobra.Command,
-	args []string,
-	sourceState *chezmoi.SourceState,
-) error {
+func (c *Config) runRemoveCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
 	targetRelPaths, err := c.targetRelPaths(sourceState, args, targetRelPathsOptions{
 		mustBeManaged: true,
 		recursive:     c.remove.recursive,
